@@ -34,14 +34,15 @@ fn resolve_local_reference(base: &Url, reference: &str) -> Option<PathBuf> {
             }
             url
         }
-        Err(_) => { return None; }
+        Err(_) => {
+            return None;
+        }
     };
 
     url.to_file_path().ok()
 }
 
 impl SourceMapBuilder {
-
     /// Creates a new source map builder and sets the file.
     pub fn new(file: Option<&str>) -> SourceMapBuilder {
         SourceMapBuilder {
@@ -106,7 +107,7 @@ impl SourceMapBuilder {
     /// Loads source contents from locally accessible files if referenced
     /// accordingly.  Returns the number of loaded source contents
     pub fn load_local_source_contents(&mut self, base_path: Option<&Path>) -> Result<usize> {
-        let mut abs_path = try!(env::current_dir());
+        let mut abs_path = env::current_dir()?;
         if let Some(path) = base_path {
             abs_path.push(path);
         }
@@ -124,9 +125,9 @@ impl SourceMapBuilder {
 
         let rv = to_read.len();
         for (src_id, path) in to_read {
-            let mut f = try!(fs::File::open(&path));
+            let mut f = fs::File::open(&path)?;
             let mut contents = String::new();
-            try!(f.read_to_string(&mut contents));
+            f.read_to_string(&mut contents)?;
             self.set_source_contents(src_id, Some(&contents));
         }
 
@@ -144,16 +145,21 @@ impl SourceMapBuilder {
     }
 
     /// Adds a new mapping to the builder.
-    pub fn add(&mut self, dst_line: u32, dst_col: u32, src_line: u32,
-               src_col: u32, source: Option<&str>,
-               name: Option<&str>) -> RawToken {
+    pub fn add(&mut self,
+               dst_line: u32,
+               dst_col: u32,
+               src_line: u32,
+               src_col: u32,
+               source: Option<&str>,
+               name: Option<&str>)
+               -> RawToken {
         let src_id = match source {
             Some(source) => self.add_source(source),
-            None => !0
+            None => !0,
         };
         let name_id = match name {
             Some(name) => self.add_name(name),
-            None => !0
+            None => !0,
         };
         let raw = RawToken {
             dst_line: dst_line,
@@ -171,9 +177,12 @@ impl SourceMapBuilder {
     /// optionally removing the name.
     pub fn add_token(&mut self, token: &Token, with_name: bool) -> RawToken {
         let name = if with_name { token.get_name() } else { None };
-        self.add(token.get_dst_line(), token.get_dst_col(),
-                 token.get_src_line(), token.get_src_col(),
-                 token.get_source(), name)
+        self.add(token.get_dst_line(),
+                 token.get_dst_col(),
+                 token.get_src_line(),
+                 token.get_src_col(),
+                 token.get_source(),
+                 name)
     }
 
     /// Strips common prefixes from the sources in the builder
@@ -199,7 +208,6 @@ impl SourceMapBuilder {
         } else {
             None
         };
-        SourceMap::new(self.file, self.tokens, self.names,
-                       self.sources, contents)
+        SourceMap::new(self.file, self.tokens, self.names, self.sources, contents)
     }
 }
